pub struct AcceptanceCriteriaProgress { /* private fields */ }Expand description
Completion counts for Markdown task-list items in a PBI body.
Implementations
Sourceimpl AcceptanceCriteriaProgress
impl AcceptanceCriteriaProgress
Sourcepub fn from_markdown(body: &str) -> Self
pub fn from_markdown(body: &str) -> Self
Parse Markdown task-list items from body.
Unordered and ordered list markers, nested items, and blockquotes are accepted. Fenced code blocks are ignored so examples in a PBI body do not affect its progress.
Sourcepub const fn is_incomplete(self) -> bool
pub const fn is_incomplete(self) -> bool
Whether at least one task-list item remains unchecked.