Localizer

Struct Localizer 

pub struct Localizer { /* private fields */ }
Message table used in the execution process.

Implementations

Source

impl Localizer

pub fn from_environment() -> Self

Determine the locale from the current process environment.

pub const fn locale(&self) -> Locale

Returns the actual selected display locale.

pub fn language_identifier(&self) -> &LanguageIdentifier

Returns Fluent’s locale identifier chosen from an environment variable.

pub fn text(&self, message: Message) -> String

Resolve Fluent messages without arguments.

pub fn lookup(&self, id: &str) -> Option<String>

Resolve any Fluent message ID.

Resolve dynamic messages that are difficult to enumerate, such as clap’s help, from the resource bundle. Return None for an unknown ID or invalid pattern so callers can keep their default wording.

pub fn format<'a>( &self, message: Message, variables: impl IntoIterator<Item = (&'a str, &'a str)>, ) -> String

Resolve messages by giving them Fluent variables.

If a built-in FTL resource is missing or cannot be formatted, return the message identifier so a resource problem cannot make the CLI or TUI undisplayable.