KeyCode

Enum KeyCode 

pub enum KeyCode {
Show 16 variants Char(char), Enter, Esc, Tab, Backspace, Delete, Insert, Left, Right, Up, Down, Home, End, PageUp, PageDown, F(u8),
}
Platform-neutral key codes used by the configuration parser and TUI adapter.

Variants



Char(char)

A printable character.



Enter

Enter/Return.



Esc

Escape.



Tab

Tab.



Backspace

Backspace.



Delete

Delete.



Insert

Insert.



Left

Left arrow.



Right

Right arrow.



Up

Up arrow.



Down

Down arrow.



Home

Home.



End

End.



PageUp

Page up.



PageDown

Page down.



F(u8)

Function key.