pub enum EditOutcome {
Updated(Box<BacklogItem>),
Unchanged,
}Expand description
Result of apply_item_edit.
Variants
Updated(Box<BacklogItem>)
The edited contents were reflected and saved (updated PBI).
Wrap it in Box to avoid size difference between variants (Unchanged has no data).
Unchanged
There was no change in the content and it was not saved.