pub enum MigrateOutcome {
Migrated {
from: StorageBackend,
to: StorageBackend,
items: usize,
sprints: usize,
},
AlreadyUsing(StorageBackend),
}Expand description
Result of migrate_storage.
Variants
Migrated
Actually migrated (migration source, migration destination, and number of items copied).
AlreadyUsing(StorageBackend)
No migration was needed because the target backend is already active.