pub enum SprintLoadWarningKind {
Capacity,
Velocity,
}Expand description
The source of a non-blocking Sprint load warning.
Variants
Capacity
The assigned point total is above the configured capacity-hours threshold.
Velocity
The assigned point total is above the historical velocity threshold.
Implementations