common_dod

Function common_dod 

pub async fn common_dod(project_dir: &Path) -> Result<Option<String>>
Load the board’s common DoD, returning None when the file is absent or empty.

Return the content trimmed of leading and trailing whitespace. Return Error::NotInitialized when the board is uninitialized.