remove_item

Function remove_item 

pub async fn remove_item(
    project_dir: &Path,
    id: &ItemId,
    permanent: bool,
) -> Result<RemoveOutcome>
Delete PBI with id. The default is archive backup, and if permanent is true, physical deletion is performed.

A non-destructive operation that moves the archive to .pinto/archive/<id>.md (it can be tracked with Git and can be restored from the backup location). permanent is a hard delete that cannot be undone and requires an explicit flag (--force) in the CLI. Error::NotInitialized if the board is uninitialized, Error::NotFound if the corresponding ID does not exist.