pub struct Burndown {
pub sprint_id: SprintId,
pub sprint_title: String,
pub metric: BurndownMetric,
pub total: u32,
pub days: Vec<BurndownDay>,
}Expand description
Sprint burndown summary.
Fields
sprint_id: SprintIdID of the target sprint.
sprint_title: StringDisplay title of the target sprint.
metric: BurndownMetricAggregated metrics (points or counts).
total: u32Total amount of work on the period start date (burndown starting point).
days: Vec<BurndownDay>Daily observation points (in ascending order from start date to end date, inclusive).