pinto — A lightweight CLI/TUI backlog/kanban board for Scrum.
This crate provides the domain and service layers used by the CLI (main.rs) and TUI.
See docs/DESIGN.md for detailed design.
Modules
- automation
- A format for safely receiving operation plans generated by AI agents.
- backlog
- Domain model.
- error
- The crate-wide error type.
- i18n
- A lightweight internationalization infrastructure for CLI/TUI.
- kanban_
keys - Configurable Kanban key names and platform-neutral key matching.
- rank
- Lexicographic rank for fractional indexing.
- service
- Use case (application service).
- sprint
- Sprint model.
- storage
- Persistence layer.
- template
- Plain text template to apply during creation.
- timezone
- User-facing timezone selection for human-readable timestamps.
Constants
- VERSION
- Crate version (synced with
Cargo.toml).