pub struct Localizer { /* private fields */ }Expand description
Message table used in the execution process.
Implementations
Sourceimpl Localizer
impl Localizer
Sourcepub fn from_environment() -> Self
pub fn from_environment() -> Self
Determine the locale from the current process environment.
Sourcepub fn language_identifier(&self) -> &LanguageIdentifier
pub fn language_identifier(&self) -> &LanguageIdentifier
Returns Fluent’s locale identifier chosen from an environment variable.
Sourcepub fn lookup(&self, id: &str) -> Option<String>
pub fn lookup(&self, id: &str) -> Option<String>
Resolve any Fluent message ID.
Resolve dynamic messages that are difficult to enumerate, such as clap’s help, from the
resource bundle. Return None for an unknown ID or invalid pattern so callers can keep
their default wording.
Sourcepub fn format<'a>(
&self,
message: Message,
variables: impl IntoIterator<Item = (&'a str, &'a str)>,
) -> String
pub fn format<'a>( &self, message: Message, variables: impl IntoIterator<Item = (&'a str, &'a str)>, ) -> String
Resolve messages by giving them Fluent variables.
If a built-in FTL resource is missing or cannot be formatted, return the message identifier so a resource problem cannot make the CLI or TUI undisplayable.