pub enum KeyAction {
Show 32 variants
Quit,
Shell,
SelectLeft,
SelectRight,
SelectUp,
SelectDown,
MoveLeft,
MoveRight,
ReorderUp,
ReorderDown,
ToggleExpand,
Add,
DependencyAdd,
DependencyRemove,
Parent,
Edit,
Reload,
Maximize,
Search,
RegexSearch,
Details,
Help,
ClearFilter,
ConfirmQuit,
CancelQuit,
PopupClose,
PopupScrollUp,
PopupScrollDown,
PopupSelectUp,
PopupSelectDown,
PopupSelectLeft,
PopupSelectRight,
}Expand description
Actions that can be assigned one or more keys in [tui.key_bindings].
Variants
Quit
Leave Kanban mode.
Shell
Leave Kanban mode and hand control to the shell.
SelectLeft
Select the column to the left.
SelectRight
Select the column to the right.
SelectUp
Select the row above.
SelectDown
Select the row below.
MoveLeft
Move the selected item to the column on the left.
MoveRight
Move the selected item to the column on the right.
ReorderUp
Reorder the selected item upwards.
ReorderDown
Reorder the selected item downwards.
ToggleExpand
Expand or collapse the selected parent item.
Add
Open the form for adding a new PBI.
DependencyAdd
Open the form for adding a dependency to the selected PBI.
DependencyRemove
Open the form for removing a dependency from the selected PBI.
Parent
Open the form for setting or clearing the selected PBI’s parent.
Edit
Edit the selected item.
Reload
Reload the board.
Maximize
Toggle maximized-column mode.
Search
Open substring search.
RegexSearch
Open regular-expression search.
Details
Open or close the selected item’s details.
Help
Open or close the Kanban help window.
ClearFilter
Clear an active search filter.
ConfirmQuit
Confirm leaving from the quit dialog.
CancelQuit
Cancel leaving from the quit dialog.
PopupClose
Close the details popup.
PopupScrollUp
Scroll the details popup upwards.
PopupScrollDown
Scroll the details popup downwards.
PopupSelectUp
Select the row above while the details popup is open.
PopupSelectDown
Select the row below while the details popup is open.
PopupSelectLeft
Select the column to the left while the details popup is open.
PopupSelectRight
Select the column to the right while the details popup is open.
Implementations